summary refs log tree commit diff
path: root/tests
diff options
context:
space:
mode:
authorMathieu Velten <mathieuv@matrix.org>2022-08-03 14:46:46 +0200
committerMathieu Velten <mathieuv@matrix.org>2022-08-03 14:46:46 +0200
commit4cc2f3e9901bb545fa103a550630eda93bab84f5 (patch)
treec3b3186713ad40c31f282f29d658fc2ec1955114 /tests
parentType mistake (diff)
downloadsynapse-4cc2f3e9901bb545fa103a550630eda93bab84f5.tar.xz
Use org.matrix.unstable prefix
Diffstat (limited to 'tests')
-rw-r--r--tests/rest/client/test_sync.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/rest/client/test_sync.py b/tests/rest/client/test_sync.py
index 6937dd4489..e45436af4f 100644
--- a/tests/rest/client/test_sync.py
+++ b/tests/rest/client/test_sync.py
@@ -991,7 +991,7 @@ class ToDeviceLimitTestCase(unittest.HomeserverTestCase):
         )
         self.assertEqual(chan.code, 200, chan.result)
 
     # This does an incremental sync for user kermit with do_not_use_to_device_limit
     # setted and check the number of returned to_device msgs against
     # expected_to_device_msgs value
     def _limited_sync_and_check(
@@ -999,7 +999,7 @@ class ToDeviceLimitTestCase(unittest.HomeserverTestCase):
     ) -> None:
         channel = self.make_request(
             "GET",
-            f'/sync?since={self.next_batch}&filter={{"do_not_use_to_device_limit": {to_device_limit}}}',
+            f'/sync?since={self.next_batch}&filter={{"org.matrix.unstable.to_device_limit": {to_device_limit}}}',
             access_token=self.tok,
         )
         self.assertEqual(channel.code, 200)
@@ -991,7 +991,7 @@ class ToDeviceLimitTestCase(unittest.HomeserverTestCase):
         self.assertEqual(chan.code, 200, chan.result)
 
-    # This does an incremental sync for user kermit with do_not_use_to_device_limit
+    # This does an incremental sync for user kermit with org.matrix.unstable.to_device_limit
     # setted and check the number of returned to_device msgs against
     # expected_to_device_msgs value